summaryrefslogtreecommitdiff
path: root/chip/g/idle.c
diff options
context:
space:
mode:
Diffstat (limited to 'chip/g/idle.c')
-rw-r--r--chip/g/idle.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/chip/g/idle.c b/chip/g/idle.c
index b376f14e82..0d4656a8c6 100644
--- a/chip/g/idle.c
+++ b/chip/g/idle.c
@@ -211,8 +211,8 @@ void __idle(void)
if (!idle_action)
idle_action = idle_default;
- /* Disable sleep until 3 minutes after init */
- delay_sleep_by(3 * MINUTE);
+ /* Disable sleep for 20 seconds after init */
+ delay_sleep_by(20 * SECOND);
while (1) {